# Changelog

## 0.0.1 – initial release
- PEP 621 / Hatch build (wheel + sdist)
- Core API: bures_angle, effective_dimension, entropy/mutual information helpers, compute_Y
- OIDC GitHub Actions workflow for PyPI publishing
- BSD-3-Clause license

